import React, { useState, useEffect } from 'react';
import { Form, Modal, Input, Select, Radio, Checkbox, notification, Tooltip } from 'antd';

import {
    getField,loadTableFields
} from '@/services/platform/bs'
import styles from './index.less'
import ChangeAdd from './changeAdd'
import { PlusSquareOutlined } from '@ant-design/icons';
const AddModal = props => {
    const { callBackSubmit = () => { }, isType, itemData, isVisible,formObj1 } = props;
    const [loading, setLoading] = useState(false);
    const [fieldName, setFieldName] = useState([]); // 弹窗
    const [characteristics, setCharacteristics] = useState(['文本','数值','唯一值文本','多行文本','编码','地址','本人部门','本人姓名','本人ID','选择器','搜索选择器','值选择器','值复选器','业务选择器','可编辑值选择器','平铺值选择器','站点选择器','人员选择器','人员选择器新','城市选择器','台账选择器','附近','可预览附件','图片','可预览图片','录音','视频','日期时间','日期','日期月份','日期年份','日期周','时分秒','设备选择','坐标控件','区域控件','路径控件','智能抄表','二维码识别','设备二维码','位置坐标'])
    const [visible, setVisible] = useState(false); // 弹窗
    const [type, setType] = useState(''); // 弹窗类型
    const [formObj, setFormObj] = useState({ rule: [], numerical: '' });
    const { TextArea } = Input;
    const [form] = Form.useForm();
    const { Item } = Form;
    // 提交
    const onSubmit = () => {
        form.validateFields().then(validate => {
            if (validate) {
                setLoading(true);
                let obj = form.getFieldsValue();
                updateTable({
                    interfaceName: obj.interfaceText,
                    tableID,
                    tableName: obj.tableName,
                    tableStyle: obj.tableStyle,
                    alias: obj.tableAlias,
                    officeTmpl: obj.officeTmpl
                }).then(res => {
                    setLoading(false);
                    console.log(res.msg, 'res.msg');
                    if (res.msg === "Ok" || res.msg === "") {
                        form.resetFields();
                        callBackSubmit();
                        notification.success({
                            message: '提示',
                            duration: 3,
                            description: '修改成功',
                        });

                    } else {
                        notification.error({
                            message: '提示',
                            duration: 3,
                            description: res.msg,
                        });
                    }
                })

            }
        });
    };


    useEffect(() => {
        if (isType != '') {
            let req1 = getField({ fieldID: itemData.ID })
            let req2 = loadTableFields({ tableName: formObj1.tableName })
            Promise.all([req1,req2]).then(res=>{
                res[0].msg==='Ok' && form.setFieldsValue({ ...res[0].data.root })
                res[1].msg==='Ok' && setFieldName(res[1].data.root)
            })
        }

    }, [isVisible]);



    const layout = {
        layout: 'horizontal',
        labelCol: {
            span: 4,
        },
        wrapperCol: {
            span: 16,
        },
    };

    const handleChange = (value) => {
        form.setFieldsValue({ schemename: value });
    }
    const onChange = () => {

    }

    const onOK = prop => {
        setVisible(false);
        form.setFieldsValue({ ValidationRule: prop });
    };
    const add = (type) => {
        let obj = form.getFieldsValue();
        let data = { ...formObj }
        if (obj.ValidationRule) {
            let arr = obj.ValidationRule.split(",")
            arr.map(item => {
                switch (item) {
                    case 'required':
                        data.rule.push(item);
                        break;
                    case 'emphasis':
                        data.rule.push(item);
                        break;
                    case 'sensitive':
                        data.rule.push(item);
                        break;
                    default:
                        data.numerical = item
                }
            })
        }else{
            data ={ rule: [], numerical: '' }
        }
        setFormObj(data)
        setType(type);
        setVisible(true);
    }
    return (
        <>
            <Modal
                title='修改'
                bodyStyle={{ width: '100%', minHeight: '100px' }}
                style={{ top: '150px' }}
                width="700px"
                destroyOnClose
                maskClosable={false}
                cancelText="取消"
                okText="确认"
                {...props}
                visible={isVisible}
                onOk={() => onSubmit()}
                confirmLoading={loading}
                forceRender={true}
                getContainer={false}
            >
                {isVisible && (
                    <Form form={form} {...layout} >
                        <Item
                            label="字段名"
                            name="Name"
                            rules={[{ required: true, message: '请输入表名' }]}
                        >
                            <Select onChange={handleChange}>
                                {fieldName.length ? fieldName.map((item, index) => { return <Select.Option key={index} value={item.fieldID}>{item.fieldName}</Select.Option>; }) : ''}
                            </Select>
                        </Item>
                        <Item
                            label="别名"
                            name="Alias"
                        >
                            <Input placeholder="请输入别名" allowClear />
                        </Item>
                        <Item
                            label="属性"
                        >
                            <Checkbox onChange={onChange}>只读</Checkbox>
                            <Checkbox onChange={onChange}>允许补正(事后修改)</Checkbox>
                        </Item>
                        <Item
                            label="同步"
                            name="tableStyle"
                        >
                            <Radio.Group>
                                <Radio value='大' style={{ marginRight: '0.5rem' }}>不同步</Radio>
                                <Radio value='中' style={{ marginRight: '0.5rem' }}>工单 → 事件</Radio>
                                <Radio value='小'>事件（上报时） → 工单</Radio>
                            </Radio.Group>
                        </Item>
                        <Item
                            label="形态"
                        >
                            <div className={styles.listEvent}>
                                <Select style={{ width: '42%' }} onChange={handleChange}>
                                    {characteristics.length ? characteristics.map((item, index) => { return <Select.Option key={index} value={item}>{item}</Select.Option>; }) : ''}
                                </Select>
                                <div className={styles.unit}>单位：<Input style={{ width: '5rem' }} placeholder="" allowClear /></div>
                                <div className={styles.unit}>宽：<Input style={{ width: '4rem' }} placeholder="" allowClear /></div>
                            </div>
                        </Item>

                        <Item
                            label="配置"
                            name="tableStyle"
                        >
                            <TextArea allowClear />
                        </Item>
                        <Item
                            label="异常值"
                        >
                            <div className={styles.listEvent}>
                                <Input style={{ width: '40%', height: '1.8rem' }} placeholder="" allowClear />
                                <Item
                                    style={{ marginLeft: '1rem' }}
                                    label="触发事件"
                                    name="tableStyle"
                                    style={{ margin: '0 0 0 1rem' }}
                                >
                                    <Select style={{ width: '10.8rem' }} onChange={handleChange}>
                                        {fieldName.length ? fieldName.map((item, index) => { return <Select.Option key={index} value={item.text}>{item.text}</Select.Option>; }) : ''}
                                    </Select>
                                </Item>
                            </div>
                        </Item>
                        <Item
                            label="预设值"
                        >
                            <div className={styles.listEvent}>
                                <Input style={{ width: '40%', height: '1.8rem' }} placeholder="" allowClear />
                                <Item
                                    style={{ marginLeft: '1rem' }}
                                    label="验证"
                                    name="ValidationRule"
                                    style={{ margin: '0 0 0 1rem' }}
                                >
                                    <Input style={{ width: '95%' }} placeholder="" allowClear />
                                </Item>
                                <Tooltip title="选择验证规则">
                                    <PlusSquareOutlined
                                        onClick={() => add('rule')}
                                        style={{ fontSize: '24px', color: '#1890FF', display: 'flex', alignItems: 'center' }}
                                    />
                                </Tooltip>
                            </div>
                        </Item>

                        <Item
                            label="字段集"
                        >
                            <div className={styles.listEvent}>
                                <Input style={{ width: '93%' }} placeholder="" allowClear />
                                <Tooltip title="字符集选择">
                                    <PlusSquareOutlined
                                        onClick={() => add('characteristics')}
                                        style={{ fontSize: '24px', color: '#1890FF', display: 'flex', alignItems: 'center', marginLeft: '0.5rem' }}
                                    />
                                </Tooltip>
                            </div>

                        </Item>
                    </Form>
                )}
            </Modal>
            <ChangeAdd
                visible={visible}
                onCancel={() => setVisible(false)}
                callBackSubmit={onOK}
                type={type}
                formObj={formObj} />
        </>
    );
};
export default AddModal;
